==> haskell-mintty-0.1.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-mintty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mintty
version: 0.1.1
id: mintty-0.1.1-74ZV8VLfdJeLnsVL6jFx4m
key: mintty-0.1.1-74ZV8VLfdJeLnsVL6jFx4m
license: BSD3
copyright: (C) 2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/mintty
synopsis: A reliable way to detect the presence of a MinTTY console on Windows
description:
    MinTTY is a Windows-specific terminal emulator for the
    widely used Cygwin and MSYS projects, which provide
    Unix-like environments for Windows. MinTTY consoles behave
    differently from native Windows consoles (such as
    @cmd.exe@ or PowerShell) in many ways, and in some cases,
    these differences make it necessary to treat MinTTY
    consoles differently in code.
    .
    The @mintty@ library provides a simple way to detect if
    your code in running in a MinTTY console on Windows. It
    exports @isMinTTY@, which does the right thing 90% of the
    time (by checking if standard error is attached to
    MinTTY), and it also exports @isMinTTYHandle@ for the
    other 10% of the time (when you want to check is some
    arbitrary handle is attached to MinTTY). As you might
    expect, both of these functions will simply return @False@
    on any non-Windows operating system.
category: System
author: Ryan Scott
exposed: True
exposed-modules:
    System.Console.MinTTY
abi: 1e91e028f62f2817e43c8777d744473a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/mintty-0.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/mintty-0.1.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/mintty-0.1.1
hs-libraries: HSmintty-0.1.1-74ZV8VLfdJeLnsVL6jFx4m
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-mintty/html/mintty.haddock
haddock-html: /usr/share/doc/haskell-mintty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mintty-0.1.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-mintty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mintty
version: 0.1.1
id: mintty-0.1.1-Bsv90ffLSDaDtMfAj7LzGz
key: mintty-0.1.1-Bsv90ffLSDaDtMfAj7LzGz
license: BSD3
copyright: (C) 2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/mintty
synopsis: A reliable way to detect the presence of a MinTTY console on Windows
description:
    MinTTY is a Windows-specific terminal emulator for the
    widely used Cygwin and MSYS projects, which provide
    Unix-like environments for Windows. MinTTY consoles behave
    differently from native Windows consoles (such as
    @cmd.exe@ or PowerShell) in many ways, and in some cases,
    these differences make it necessary to treat MinTTY
    consoles differently in code.
    .
    The @mintty@ library provides a simple way to detect if
    your code in running in a MinTTY console on Windows. It
    exports @isMinTTY@, which does the right thing 90% of the
    time (by checking if standard error is attached to
    MinTTY), and it also exports @isMinTTYHandle@ for the
    other 10% of the time (when you want to check is some
    arbitrary handle is attached to MinTTY). As you might
    expect, both of these functions will simply return @False@
    on any non-Windows operating system.
category: System
author: Ryan Scott
exposed: True
indefinite: False
exposed-modules:
    System.Console.MinTTY
abi: 00b615e4d6100ede48f202394863d67e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/mintty-0.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/mintty-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/mintty-0.1.1
hs-libraries: HSmintty-0.1.1-Bsv90ffLSDaDtMfAj7LzGz
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-mintty/html/mintty.haddock
haddock-html: /usr/share/doc/haskell-mintty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
